@@ -1,13 +1,12 @@
-import warnings
 from types import MappingProxyType
 from unittest import TestCase
 
 from itemadapter.utils import get_field_meta_from_class
-
 from tests import (
     AttrsItem,
     DataClassItem,
     PydanticModel,
+    PydanticV1Model,
     ScrapyItem,
     ScrapySubclassedItem,
 )
@@ -21,10 +20,6 @@ class DataclassTestCase(TestCase):
         self.assertFalse(DataclassAdapter.is_item(sum))
         self.assertFalse(DataclassAdapter.is_item(1234))
         self.assertFalse(DataclassAdapter.is_item(object()))
-        self.assertFalse(DataclassAdapter.is_item(ScrapyItem()))
-        self.assertFalse(DataclassAdapter.is_item(AttrsItem()))
-        self.assertFalse(DataclassAdapter.is_item(PydanticModel()))
-        self.assertFalse(DataclassAdapter.is_item(ScrapySubclassedItem()))
         self.assertFalse(DataclassAdapter.is_item("a string"))
         self.assertFalse(DataclassAdapter.is_item(b"some bytes"))
         self.assertFalse(DataclassAdapter.is_item({"a": "dict"}))
@@ -33,6 +28,26 @@ class DataclassTestCase(TestCase):
         self.assertFalse(DataclassAdapter.is_item({"a", "set"}))
         self.assertFalse(DataclassAdapter.is_item(DataClassItem))
 
+        try:
+            import attrs  # noqa: F401  # pylint: disable=unused-import
+        except ImportError:
+            pass
+        else:
+            self.assertFalse(DataclassAdapter.is_item(AttrsItem()))
+
+        if PydanticModel is not None:
+            self.assertFalse(DataclassAdapter.is_item(PydanticModel()))
+        if PydanticV1Model is not None:
+            self.assertFalse(DataclassAdapter.is_item(PydanticV1Model()))
+
+        try:
+            import scrapy  # noqa: F401  # pylint: disable=unused-import
+        except ImportError:
+            pass
+        else:
+            self.assertFalse(DataclassAdapter.is_item(ScrapyItem()))
+            self.assertFalse(DataclassAdapter.is_item(ScrapySubclassedItem()))
+
     def test_true(self):
         from itemadapter.adapter import DataclassAdapter
 
@@ -48,16 +63,3 @@ class DataclassTestCase(TestCase):
         )
         with self.assertRaises(KeyError, msg="DataClassItem does not support field: non_existent"):
             get_field_meta_from_class(DataClassItem, "non_existent")
-
-    def test_deprecated_is_instance(self):
-        from itemadapter.utils import is_dataclass_instance
-
-        with warnings.catch_warnings(record=True) as caught:
-            is_dataclass_instance(1)
-            self.assertEqual(len(caught), 1)
-            self.assertTrue(issubclass(caught[0].category, DeprecationWarning))
-            self.assertEqual(
-                "itemadapter.utils.is_dataclass_instance is deprecated"
-                " and it will be removed in a future version",
-                str(caught[0].message),
-            )
